/* GNU Mailutils -- a suite of utilities for electronic mail
   Copyright (C) 1999, 2000, 2001, 2002, 2006,
   2007, 2010 Free Software Foundation, Inc.

   GNU Mailutils is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   GNU Mailutils is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. */

#include <mailutils/stream.h>

typedef struct mu_db_file DBM_FILE;

#if defined(WITH_GDBM)

#include <gdbm.h>
#define USE_DBM
struct mu_db_file {
  char *name;
  GDBM_FILE db;
};
typedef datum DBM_DATUM;
#define MU_DATUM_SIZE(d) (d).dsize
#define MU_DATUM_PTR(d) (d).dptr

#elif defined(WITH_BDB)

#include <db.h>
#define USE_DBM

struct mu_db_file
{
  char *name;
  int lockfd;
  char *lockname;
  DB *db;
  DBC *dbc;
};

typedef DBT DBM_DATUM;
#define MU_DATUM_SIZE(d) (d).size
#define MU_DATUM_PTR(d) (d).data

#endif

#ifdef USE_DBM
struct stat;
int mu_dbm_stat (char *name, struct stat *sb);
int mu_dbm_open (char *name, DBM_FILE *db, int flags, int mode, int *ro);
int mu_dbm_close (DBM_FILE *db);
int mu_dbm_fetch (DBM_FILE *db, DBM_DATUM key, DBM_DATUM *ret);
int mu_dbm_insert (DBM_FILE *db, DBM_DATUM key, DBM_DATUM contents, int replace);
int mu_dbm_delete (DBM_FILE *db, DBM_DATUM key);
int mu_dbm_firstkey (DBM_FILE *db, DBM_DATUM *pkey);
int mu_dbm_nextkey (DBM_FILE *db, DBM_DATUM key, DBM_DATUM *pkey);
void mu_dbm_datum_free(DBM_DATUM *datum);
const char *mu_dbm_strerror (void);
#else
# define mu_dbm_datum_free(datum)
#endif

int mu_fcheck_perm (int fd, int mode);
int mu_check_perm (const char *name, int mode);

/*
 Local Variables:
 c-file-style: "gnu"
 End:
*/
